Module: Cucumber::Formatter::MessageHandlers
- Included in:
- MessageBuilder
- Defined in:
- lib/cucumber/formatter/message_handlers.rb
Overview
Common Message Handlers to be used across all message-based formatters Designed to work solely with events of type ‘Envelope`
Instance Method Summary collapse
Instance Method Details
#store_current_test_run_hook_started_id(event) ⇒ Object
8 9 10 |
# File 'lib/cucumber/formatter/message_handlers.rb', line 8 def store_current_test_run_hook_started_id(event) @current_test_run_hook_started_id = event.envelope.test_run_hook_started.id if event.envelope.test_run_hook_started end |